
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

############################
Sample usage for wordnet_lch
############################

.. include:: ../../nltk/test/wordnet_lch.doctest